@@ -56,8 +56,8 @@ for (alt in c("two.sided", "greater", "less")) {
 
   test_that("Check structure.", {
     expect_true(class(test) == "lrtest")
-    expect_true(length(test) == 3)
-    expect_true(all(names(test) == c("statistic", "p.value", "alternative")))
+    expect_true(length(test) == 4)
+    expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "alternative")))
   })
 
   test_02 <- exact_test(x = x, lambda = 1, alternative = alt)
@@ -65,6 +65,15 @@ for (alt in c("two.sided", "greater", "less")) {
     expect_true(test$p.value > .05)
     expect_true(abs(test$p.value - test_02$p.value) < .03)
   })
+
+  # .0499 instead of .05 b/c of floating point error associated with convergence.
+  CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
+  CI2 <- test$conf.int[2] - .Machine$double.eps
+  test_that("Check CI", {
+    expect_true(ifelse(is.finite(CI1), poisson_lambda_lr_test(x, CI1, alt)$p.value, .05) >= .0499)
+    expect_true(ifelse(is.finite(CI2), poisson_lambda_lr_test(x, CI2, alt)$p.value, .05) >= .0499)
+  })
+  rm(CI1, CI2)
 }
 
 ###############################################
@@ -77,8 +86,8 @@ for (alt in c("two.sided", "greater")) {
 
   test_that("Check structure.", {
     expect_true(class(test) == "lrtest")
-    expect_true(length(test) == 3)
-    expect_true(all(names(test) == c("statistic", "p.value", "alternative")))
+    expect_true(length(test) == 4)
+    expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "alternative")))
   })
 
   test_02 <- exact_test(x = x, lambda = 1, alternative = alt)
@@ -86,6 +95,17 @@ for (alt in c("two.sided", "greater")) {
     expect_true(test$p.value <= .05)
     expect_true(abs(test$p.value - test_02$p.value) < .01)
   })
+
+  CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
+  CI2 <- test$conf.int[2] - .Machine$double.eps
+  pval <- pmin(
+    ifelse(is.finite(CI1), poisson_lambda_lr_test(x, CI1, alt)$p.value, .05),
+    ifelse(is.finite(CI2), poisson_lambda_lr_test(x, CI2, alt)$p.value, .05)
+  )
+  test_that("Check CI", {
+    expect_true(pval <= .0500001)
+  })
+  rm(CI1, CI2, pval)
 }
 
 for (alt in c("two.sided", "less")) {
@@ -95,8 +115,8 @@ for (alt in c("two.sided", "less")) {
 
   test_that("Check structure.", {
     expect_true(class(test) == "lrtest")
-    expect_true(length(test) == 3)
-    expect_true(all(names(test) == c("statistic", "p.value", "alternative")))
+    expect_true(length(test) == 4)
+    expect_true(all(names(test) == c("statistic", "p.value", "conf.int", "alternative")))
   })
 
   test_02 <- exact_test(x = x, lambda = 3, alternative = alt)
@@ -104,28 +124,44 @@ for (alt in c("two.sided", "less")) {
     expect_true(test$p.value <= .05)
     expect_true(abs(test$p.value - test_02$p.value) < .01)
   })
+
+  CI1 <- test$conf.int[1] + .Machine$double.eps # Avoid boundary
+  CI2 <- test$conf.int[2] - .Machine$double.eps
+  pval <- pmin(
+    ifelse(is.finite(CI1), poisson_lambda_lr_test(x, CI1, alt)$p.value, .05),
+    ifelse(is.finite(CI2), poisson_lambda_lr_test(x, CI2, alt)$p.value, .05)
+  )
+  test_that("Check CI", {
+    expect_true(pval <= .0500001)
+  })
+  rm(CI1, CI2, pval)
 }
 
 ###############################################
 # Input checking
 ###############################################
-set.seed(1)
 test_that("x input checking works", {
-  expect_error(poisson_lambda_lr_test(c()), NULL)
-  expect_error(poisson_lambda_lr_test(rep("foo", 50)), NULL)
-  expect_error(poisson_lambda_lr_test(rpois(49, lambda = 1)), NULL)
+  expect_error(poisson_lambda_lr_test(c()), "Argument x should have at least 50 data points.")
+  expect_error(poisson_lambda_lr_test(rep("foo", 50)), "Argument x should be numeric.")
 })
 
 set.seed(1)
+x <- rpois(50, lambda = 1)
 test_that("lambda input checking works", {
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), c(1, 2)), NULL)
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), "foo"), NULL)
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), 0), NULL)
+  expect_error(poisson_lambda_lr_test(x, c(1, 2)), "The tested parameter should have length one.")
+  expect_error(poisson_lambda_lr_test(x, "foo"), "The tested parameter should be numeric.")
+  expect_error(poisson_lambda_lr_test(x, 0), "The tested parameter should be above 0.")
 })
 
-set.seed(1)
 test_that("alternative input checking works", {
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), 1, c("two.sided", "less")), NULL)
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), 1, 1), NULL)
-  expect_error(poisson_lambda_lr_test(rpois(50, lambda = 1), 1, "lesss"), NULL)
+  expect_error(poisson_lambda_lr_test(x, 1, c("two.sided", "less")), "Argument alternative should have length one.")
+  expect_error(poisson_lambda_lr_test(x, 1, 1), "Argument alternative should be a character.")
+  expect_error(poisson_lambda_lr_test(x, 1, "lesss"), "Argument alternative should be 'two.sided', 'less', or 'greater.")
+})
+
+test_that("conf.level input checking works", {
+  expect_error(poisson_lambda_lr_test(x, 1, "less", c(.50, .75)), "conf.level should have length one.")
+  expect_error(poisson_lambda_lr_test(x, 1, "less", "foo"), "conf.level should be numeric.")
+  expect_error(poisson_lambda_lr_test(x, 1, "less", 0), "conf.level should between zero and one.")
+  expect_error(poisson_lambda_lr_test(x, 1, "less", 1), "conf.level should between zero and one.")
 })
